@@ -281,7 +281,7 @@ class PlaceService(BaseRdbmsService):
         areas = [
             area
             for area in areas
-            if area.level == 0
+            if area.area_level == 0
         ]
 
         area = None if len(areas) == 0 else areas[0]
